@@ -68,7 +68,7 @@ atexit.register(info.threadpool.shutdown)
 def version(conf):
     '''Check if config version is supported. Currently, only 1.0 is supported'''
     if conf != 1.0:
-        raise NotImplementedError('version: %s is not supported. Only 1.0', conf)
+        raise NotImplementedError(f'version: {conf} is not supported. Only 1.0')
 
 
 def log(conf):
@@ -86,7 +86,7 @@ def log(conf):
                     try:
                         os.makedirs(folder)
                     except OSError:
-                        app_log.exception('log: %s: cannot create folder %s', handler, folder)
+                        app_log.exception(f'log: {handler}: cannot create folder {folder}')
     try:
         logging.config.dictConfig(conf)
     except (ValueError, TypeError, AttributeError, ImportError):
@@ -108,8 +108,8 @@ class GramexApp(tornado.web.Application):
             log_method = gramex.cache.app_log.error
         request_time = 1000.0 * handler.request.request_time()
         handler_name = getattr(handler, 'name', handler.__class__.__name__)
-        log_method("%d %s %.2fms %s", handler.get_status(),
-                   handler._request_summary(), request_time, handler_name)
+        summary = handler._request_summary()
+        log_method(f"{handler.get_status()} {summary} {request_time:.2f}ms {handler_name}")
 
     def clear_handlers(self):
         '''
@@ -161,13 +161,13 @@ def app(conf):
 
             # browser: True opens the application home page on localhost.
             # browser: url opens the application to a specific URL
-            url = 'http://127.0.0.1:%d/' % conf.listen.port
+            url = f'http://127.0.0.1:{conf.listen.port}/'
             if conf.browser:
                 if isinstance(conf.browser, str):
                     url = urljoin(url, conf.browser)
                 try:
                     browser = webbrowser.get()
-                    app_log.info('Opening %s in %s browser', url, browser.__class__.__name__)
+                    app_log.info(f'Opening {url} in {browser.__class__.__name__} browser')
                     browser.open(url)
                 except webbrowser.Error:
                     app_log.info('Unable to open browser')
@@ -242,7 +242,7 @@ def schedule(conf):
             task.call_later()
             continue
         try:
-            app_log.info('Initialising schedule:%s', name)
+            app_log.info(f'Initialising schedule:{name}')
             _cache[_key] = scheduler.Task(name, sched, info.threadpool,
                                           ioloop=info._main_ioloop)
             info.schedule[name] = _cache[_key]
@@ -282,15 +282,15 @@ def create_alert(name, alert):
     # Configure email service
     if alert.get('service', None) is None:
         if len(info.email) > 0:
-            alert['service'] = list(info.email.keys())[0]
-            app_log.warning('alert: %s: using first email service: %s', name, alert['service'])
+            service = alert['service'] = list(info.email.keys())[0]
+            app_log.warning(f'alert: {name}: using first email service: {service}')
         else:
-            app_log.error('alert: %s: define an email: service to use', name)
+            app_log.error(f'alert: {name}: define an email: service to use')
             return
     service = alert['service']
     mailer = info.email.get(service, None)
     if mailer is None:
-        app_log.error('alert: %s: undefined email service: %s', name, service)
+        app_log.error(f'alert: {name}: undefined email service: {service}')
         return
 
     # - Warn if to, cc, bcc exists and is not a string or list of strings. Ignore incorrect
@@ -299,29 +299,29 @@ def create_alert(name, alert):
 
     # Error if to, cc, bcc are all missing, return None
     if not any(key in alert for key in ['to', 'cc', 'bcc']):
-        app_log.error('alert: %s: missing to/cc/bcc', name)
+        app_log.error(f'alert: {name}: missing to/cc/bcc')
         return
     # Ensure that config has the right type (str, dict, list)
     contentfields = ['body', 'html', 'bodyfile', 'htmlfile', 'markdown', 'markdownfile']
     addr_fields = ['to', 'cc', 'bcc', 'reply_to', 'on_behalf_of', 'from']
     for key in ['subject'] + addr_fields + contentfields:
         if not isinstance(alert.get(key, ''), (str, list)):
-            app_log.error('alert: %s.%s: %r must be a list or str', name, key, alert[key])
+            app_log.error(f'alert: {name}.{key}: {alert[key]!r} must be a list or str')
             return
     if not isinstance(alert.get('images', {}), dict):
-        app_log.error('alert: %s.images: %r is not a dict', name, alert['images'])
+        app_log.error(f'alert: {name}.images: {alert["images"]!r} is not a dict')
         return
     if not isinstance(alert.get('attachments', []), list):
-        app_log.error('alert: %s.attachments: %r is not a list', name, alert['attachments'])
+        app_log.error(f'alert: {name}.attachments: {alert["attachments"]!r} is not a list')
         return
 
     # Warn if subject is missing
     if 'subject' not in alert:
-        app_log.warning('alert: %s: missing subject', name)
+        app_log.warning(f'alert: {name}: missing subject')
 
     # Warn if body, html, bodyfile, htmlfile keys are missing
     if not any(key in alert for key in contentfields):
-        app_log.warning('alert: %s: missing body/html/bodyfile/htmlfile/...', name)
+        app_log.warning(f'alert: {name}: missing body/html/bodyfile/htmlfile/...')
 
     # Pre-compile data.
     #   - `data: {key: [...]}` -- loads data in-place
@@ -343,20 +343,19 @@ def create_alert(name, alert):
                 elif isinstance(dataset, list) or 'url' in dataset:
                     datasets[key] = dataset
                 else:
-                    app_log.error('alert: %s.data: %s is missing url:', name, key)
+                    app_log.error(f'alert: {name}.data: {key} is missing url:')
         else:
-            app_log.error('alert: %s.data: must be a data file or dict. Not %s',
-                          name, repr(alert['data']))
+            app_log.error(f'alert: {name}.data: must be data file or dict. Not {alert["data"]!r}')
 
     if 'each' in alert and alert['each'] not in datasets:
-        app_log.error('alert: %s.each: %s is not in data:', name, alert['each'])
+        app_log.error(f'alert: {name}.each: {alert["each"]} is not in data:')
         return
 
     vars = {key: None for key in datasets}
     vars.update({'config': None, 'args': None})
     condition = build_transform(
         {'function': alert.get('condition', 'True')},
-        filename='alert: %s' % name, vars=vars, iter=False)
+        filename=f'alert: {name}', vars=vars, iter=False)
 
     alert_logger = logging.getLogger('gramex.alert')
 
@@ -375,7 +374,7 @@ def create_alert(name, alert):
         elif isinstance(result, dict):
             data.update(result)
         elif not result:
-            app_log.debug('alert: %s stopped. condition = %s', name, result)
+            app_log.debug(f'alert: {name} stopped. condition = {result}')
             return
         if 'each' in alert:
             each_data = data[alert['each']]
@@ -386,8 +385,8 @@ def create_alert(name, alert):
             elif hasattr(each_data, 'iterrows'):
                 each += list(each_data.iterrows())
             else:
-                raise ValueError('alert: %s: each: data.%s must be dict/list/DF, not %s' % (
-                                 name, alert['each'], type(each_data)))
+                raise ValueError(f'alert: {name}: each: data.{alert["each"]} must be ' +
+                                 'dict/list/DF, not {type(each_data)}')
         else:
             each.append((0, None))
 
@@ -432,9 +431,9 @@ def create_alert(name, alert):
                         bytestoread = 80
                         first_line = temp_file.read(bytestoread)
                     # TODO: let admin know that the image was not processed
-                    app_log.error('alert: %s: %s: %d (%s) not an image: %s\n%r', name,
-                                  cid, urldata['r'].status_code, urldata['content_type'],
-                                  urlpath, first_line)
+                    app_log.error(f'alert: {name}: {cid}: {urldata["r"].status_code} '
+                                  f'({urldata["content_type"]}) not an image: {urlpath}\n'
+                                  f'{first_line!r}')
         if 'attachments' in alert:
             mail['attachments'] = [
                 urlfetch(_tmpl(v).generate(**data).decode('utf-8'), headers=headers)
@@ -448,12 +447,12 @@ def create_alert(name, alert):
         callback with all email arguments. Else sends the email.
         If args= is specified, add it as data['args'].
         '''
-        app_log.info('alert: %s running', name)
+        app_log.info(f'alert: {name} running')
         data, each, fail = {'config': alert, 'args': {} if args is None else args}, [], []
         try:
             load_datasets(data, each)
         except Exception as e:
-            app_log.exception('alert: %s data processing failed', name)
+            app_log.exception(f'alert: {name} data processing failed')
             fail.append({'error': e})
 
         retval = []
@@ -462,7 +461,7 @@ def create_alert(name, alert):
             try:
                 retval.append(AttrDict(index=index, row=row, mail=create_mail(data)))
             except Exception as e:
-                app_log.exception('alert: %s[%s] templating (row=%r)', name, index, row)
+                app_log.exception(f'alert: {name}[{index}] templating (row={row!r})')
                 fail.append({'index': index, 'row': row, 'error': e})
 
         callback = mailer.mail if not callable(callback) else callback
@@ -472,7 +471,7 @@ def create_alert(name, alert):
                 callback(**v.mail)
             except Exception as e:
                 fail.append({'index': v.index, 'row': v.row, 'mail': v.mail, 'error': e})
-                app_log.exception('alert: %s[%s] delivery (row=%r)', name, v.index, v.row)
+                app_log.exception(f'alert: {name}[{v.index}] delivery (row={v.row!r})')
             else:
                 done.append(v)
                 event = {
@@ -491,7 +490,7 @@ def create_alert(name, alert):
             if notify is not None:
                 notify.run(callback=callback, args=args)
             else:
-                app_log.error('alert: %s.notify: alert %s not defined', name, notification_name)
+                app_log.error(f'alert: {name}.notify: alert {notification_name} not defined')
         return args
 
     return run_alert
@@ -508,7 +507,7 @@ def alert(conf):
             task = info.alert[name] = _cache[_key]
             task.call_later()
             continue
-        app_log.info('Initialising alert: %s', name)
+        app_log.info(f'Initialising alert: {name}')
         schedule = {key: alert[key] for key in schedule_keys if key in alert}
         if 'thread' in alert:
             schedule['thread'] = alert['thread']
@@ -519,7 +518,7 @@ def alert(conf):
                                               ioloop=info._main_ioloop)
                 info.alert[name] = _cache[_key]
             except Exception:
-                app_log.exception('Failed to initialize alert: %s', name)
+                app_log.exception(f'Failed to initialize alert: {name}')
 
 
 def threadpool(conf):
@@ -591,35 +590,34 @@ def _get_cache_key(conf, name):
     for key in keys:
         parts = key.split('.', 2)
         if len(parts) < 2:
-            app_log.warning('url: %s: ignoring invalid cache key %s', name, key)
+            app_log.warning(f'url:{name}: ignoring invalid cache key {key}')
             continue
         # convert second part into a Python string representation
         val = repr(parts[1])
         if parts[0] == 'request':
-            key_getters.append('u(getattr(request, %s, missing))' % val)
+            key_getters.append(f'str(getattr(request, {val}, missing))')
         elif parts[0].startswith('header'):
-            key_getters.append('request.headers.get(%s, missing)' % val)
+            key_getters.append(f'request.headers.get({val}, missing)')
         elif parts[0].startswith('cookie'):
             key_getters.append(
-                'request.cookies[%s].value if %s in request.cookies else missing' % (val, val))
+                f'request.cookies[{val}].value if {val} in request.cookies else missing')
         elif parts[0].startswith('user'):
-            key_getters.append('u(handler.current_user.get(%s, missing)) '
-                               'if handler.current_user else missing' % val)
+            key_getters.append(f'str(handler.current_user.get({val}, missing)) '
+                               'if handler.current_user else missing')
         elif parts[0].startswith('arg'):
-            key_getters.append('argsep.join(handler.args.get(%s, [missing]))' % val)
+            key_getters.append(f'argsep.join(handler.args.get({val}, [missing]))')
         else:
-            app_log.warning('url: %s: ignoring invalid cache key %s', name, key)
+            app_log.warning(f'url:{name}: ignoring invalid cache key: {key}')
     # If none of the keys are valid, use the default request key
     if not len(key_getters):
         key_getters = [default_key]
 
     method = 'def cache_key(handler):\n'
     method += '\trequest = handler.request\n'
-    method += '\treturn (%s)' % ', '.join(key_getters)
+    method += f'\treturn ({", ".join(key_getters)})'
     context = {
         'missing': '~',
         'argsep': ', ',         # join args using comma
-        'u': str                # convert to unicode
     }
     # exec() is safe here since the code is constructed entirely in this function
     exec(method, context)       # nosec: frozen input
@@ -668,7 +666,7 @@ def _cache_generator(conf, name):
     default_store = list(info.cache.keys())[0] if len(info.cache) > 0 else None
     store_name = conf.get('store', default_store)
     if store_name not in info.cache:
-        app_log.warning('url: %s: store %s missing', name, store_name)
+        app_log.warning(f'url:{name}: store {store_name} missing', name, store_name)
     store = info.cache.get(store_name)
 
     url_cache_key = _get_cache_key(conf, name)
@@ -698,18 +696,18 @@ def url(conf):
             info.url[name] = _cache[_key]
             continue
         if 'pattern' not in spec:
-            app_log.error('url: %s: no pattern: specified', name)
+            app_log.error(f'url:{name}: no pattern: specified')
             continue
         # service: is an alias for handler: and has higher priority
         if 'service' in spec:
             spec.handler = spec.service
         if 'handler' not in spec:
-            app_log.error('url: %s: no service: or handler: specified', name)
+            app_log.error(f'url:{name}: no service: or handler: specified')
             continue
-        app_log.debug('url: %s (%s) %s', name, spec.handler, spec.get('priority', ''))
+        app_log.debug(f'url:{name} ({spec.handler}) {spec.get("priority", "")}')
         handler_class = locate(str(spec.handler), modules=['gramex.handlers'])
         if handler_class is None:
-            app_log.error('url: %s: ignoring missing handler %s', name, spec.handler)
+            app_log.error(f'url:{name}: ignoring missing handler {spec.handler}')
             continue
 
         # Create a subclass of the handler with additional attributes.
@@ -724,7 +722,7 @@ def url(conf):
         # Ensure that there's a kwargs: dict in the spec
         spec.setdefault('kwargs', AttrDict())
         if not isinstance(spec.kwargs, dict):
-            app_log.error('url: %s kwargs must be a dict, not %r', name, spec.kwargs)
+            app_log.error(f'url:{name} kwargs must be a dict, not {spec.kwargs!r}')
             spec.kwargs = AttrDict()
         # If there's a setup method, call it to initialize the class
         if hasattr(handler_class, 'setup'):
@@ -732,7 +730,7 @@ def url(conf):
                 handler.setup_default_kwargs()      # Updates spec.kwargs with base handlers
                 handler.setup(**spec.kwargs)
             except Exception:
-                app_log.exception('url: %s (%s) invalid configuration', name, spec.handler)
+                app_log.exception(f'url:{name} ({spec.handler}) invalid configuration')
                 # Since we can't set up the handler, all requests must report the error instead
                 class_vars['exc_info'] = sys.exc_info()
                 error_handler = locate('SetupFailedHandler', modules=['gramex.handlers'])
@@ -748,10 +746,10 @@ def url(conf):
                 kwargs=spec.kwargs,
             )
         except re.error:
-            app_log.error('url: %s: pattern: %r is invalid', name, spec.pattern)
+            app_log.error(f'url:{name}: pattern: {spec.pattern!r} is invalid')
             continue
         except Exception:
-            app_log.exception('url: %s: setup failed', name)
+            app_log.exception(f'url:{name}: setup failed')
             continue
         info.url[name] = _cache[_key] = handler_entry
 
@@ -776,10 +774,10 @@ def watch(conf):
             watcher.watch(name, **_cache[_key])
             continue
         if 'paths' not in config:
-            app_log.error('watch:%s has no "paths"', name)
+            app_log.error(f'watch:{name} has no "paths"')
             continue
         if not set(config.keys()) & events:
-            app_log.error('watch:%s has no events (on_modified, ...)', name)
+            app_log.error(f'watch:{name} has no events (on_modified, ...)')
             continue
         if not isinstance(config['paths'], (list, set, tuple)):
             config['paths'] = [config['paths']]
@@ -788,7 +786,7 @@ def watch(conf):
                 if not callable(config[event]):
                     config[event] = locate(config[event], modules=['gramex.transforms'])
                     if not callable(config[event]):
-                        app_log.error('watch:%s.%s is not callable', name, event)
+                        app_log.error(f'watch:{name}.{event} is not callable')
                         config[event] = lambda event: None
         _cache[_key] = config
         watcher.watch(name, **_cache[_key])
@@ -812,7 +810,7 @@ def cache(conf):
     for name, config in conf.items():
         cache_type = config['type']
         if cache_type not in _cache_defaults:
-            app_log.warning('cache: %s has unknown type %s', name, config.type)
+            app_log.warning(f'cache:{name} has unknown type {config.type}')
             continue
         config = merge(dict(config), _cache_defaults[cache_type], mode='setdefault')
         if cache_type == 'memory':
@@ -828,7 +826,7 @@ def cache(conf):
             try:
                 info.cache[name] = urlcache.RedisCache(path=path, maxsize=config['size'])
             except Exception:
-                app_log.exception('cache: %s cannot connect to redis', name)
+                app_log.exception(f'cache:{name} cannot connect to redis')
         # if default: true, make this the default cache for gramex.cache.{open,query}
         if config.get('default'):
             for key in ['_OPEN_CACHE', '_QUERY_CACHE']:
@@ -902,11 +900,11 @@ def sms(conf):
             continue
         notifier_type = config.pop('type')
         if notifier_type not in sms_notifiers:
-            raise ValueError('sms: %s: Unknown type: %s' % (name, notifier_type))
+            raise ValueError(f'sms:{name}: Unknown type: {notifier_type}')
         try:
             info.sms[name] = _cache[_key] = sms_notifiers[notifier_type](**config)
         except Exception:
-            app_log.exception('sms: %s: Cannot setup %s' % (name, notifier_type))
+            app_log.exception(f'sms:{name}: Cannot setup {notifier_type}')
 
 
 def encrypt(conf):
@@ -955,7 +953,7 @@ def gramexlog(conf):
             except Exception:
                 # TODO: If the connection broke, re-create it
                 # This generic exception should be caught for thread to continue its execution
-                app_log.exception('gramexlog: push to %s failed', app)
+                app_log.exception(f'gramexlog: push to {app} failed')
         if 'handle' in info.gramexlog:
             ioloop.remove_timeout(info.gramexlog.handle)
         # Call again after flush seconds
