@@ -6,7 +6,7 @@ from lxml import etree      # nosec: lxml is safe   # noqa: F401 - other modules
 from . import server
 from nose.tools import eq_, ok_
 from orderedattrdict import AttrDict
-from pandas.util.testing import assert_frame_equal as afe   # noqa: F401 - other modules use this
+from pandas.testing import assert_frame_equal as afe   # noqa: F401 - other modules use this
 
 tempfiles = AttrDict()
 folder = os.path.dirname(os.path.abspath(__file__))
@@ -14,8 +14,6 @@ folder = os.path.dirname(os.path.abspath(__file__))
 
 def setUp():
     # Remove uploads folder before Gramex locks .meta.h5
-    # This may fail on Python 2.7 on Windows due to unicode characters.
-    # Delete tests/uploads/ manually in that case
     upload_path = os.path.join(folder, 'uploads')
     if os.path.exists(upload_path):
         shutil.rmtree(upload_path)
