@@ -5,14 +5,13 @@ Used by ../testlib/
 import os
 import sqlalchemy as sa
 from nose.plugins.skip import SkipTest
-from gramex.config import str_utf8
 
 folder = os.path.dirname(os.path.abspath(__file__))
 
 
 def mysql_create_db(server, db, **tables):
     url = 'mysql+pymysql://root@%s/' % server
-    engine = sa.create_engine(url + '?charset=utf8', encoding=str_utf8)
+    engine = sa.create_engine(url + '?charset=utf8', encoding='utf-8')
     try:
         engine.connect()
     except sa.exc.OperationalError:
@@ -20,7 +19,7 @@ def mysql_create_db(server, db, **tables):
     engine.execute("DROP DATABASE IF EXISTS %s" % db)
     engine.execute("CREATE DATABASE %s CHARACTER SET utf8 COLLATE utf8_general_ci" % db)
     engine.dispose()
-    engine = sa.create_engine(url + db + '?charset=utf8', encoding=str_utf8)
+    engine = sa.create_engine(url + db + '?charset=utf8', encoding='utf-8')
     for table_name, data in tables.items():
         data.to_sql(table_name, con=engine, index=False)
     engine.dispose()
@@ -29,14 +28,14 @@ def mysql_create_db(server, db, **tables):
 
 def mysql_drop_db(server, db):
     url = 'mysql+pymysql://root@%s/' % server
-    engine = sa.create_engine(url, encoding=str_utf8)
+    engine = sa.create_engine(url, encoding='utf-8')
     engine.execute("DROP DATABASE IF EXISTS %s" % db)
     engine.dispose()
 
 
 def postgres_create_db(server, db, **tables):
     url = 'postgresql://postgres@%s/' % server
-    engine = sa.create_engine(url, encoding=str_utf8)
+    engine = sa.create_engine(url, encoding='utf-8')
     try:
         conn = engine.connect()
     except sa.exc.OperationalError:
@@ -46,7 +45,7 @@ def postgres_create_db(server, db, **tables):
     conn.execute('commit')
     conn.execute("CREATE DATABASE %s ENCODING 'UTF8'" % db)
     conn.close()
-    engine = sa.create_engine(url + db, encoding=str_utf8)
+    engine = sa.create_engine(url + db, encoding='utf-8')
     for table_name, data in tables.items():
         if '.' in table_name:
             schema, table_name = table_name.rsplit('.', 1)
@@ -59,7 +58,7 @@ def postgres_create_db(server, db, **tables):
 
 def postgres_drop_db(server, db):
     url = 'postgresql://postgres@%s/' % server
-    engine = sa.create_engine(url, encoding=str_utf8)
+    engine = sa.create_engine(url, encoding='utf-8')
     conn = engine.connect()
     conn.execute('commit')
     # Terminate all other sessions using the test_datahandler database
@@ -77,7 +76,7 @@ def sqlite_create_db(db, **tables):
     if os.path.exists(path):
         os.unlink(path)
     url = 'sqlite:///' + path
-    engine = sa.create_engine(url, encoding=str_utf8)
+    engine = sa.create_engine(url, encoding='utf-8')
     for table_name, data in tables.items():
         # sqlite limits SQLITE_MAX_VARIABLE_NUMBER to 999
         # Ensure # columns * chunksize < 999
